@@ -189,6 +189,9 @@ class Plugin():
             for k in tmp:
                 new_m = tmp[k]
                 for o in new_m:
+                    mthd = new_m[o]['operationId']
+                    if not self.halo.settings['mservices'][self.service]['record']['methods'][mthd]:
+                        continue
                     if '200' in new_m[o]['responses']:
                         if 'items' in new_m[o]['responses']['200']['schema']:
                             props = new_m[o]['responses']['200']['schema']['items']['properties']
@@ -199,7 +202,6 @@ class Plugin():
                             props = new_m[o]['responses']['201']['schema']['items']['properties']
                         else:
                             props = new_m[o]['responses']['201']['schema']['properties']
-                    mthd = new_m[o]['operationId']
                     for p in props:
                         for target in self.halo.settings['mservices'][self.service]['record']['methods'][mthd]['refactor']:
                             fields = target['field'].split(".")
@@ -230,6 +232,9 @@ class Plugin():
             for k in tmp:
                 new_m = tmp[k]
                 for o in new_m:
+                    mthd = new_m[o]['operationId']
+                    if not self.halo.settings['mservices'][self.service]['record']['methods'][mthd]:
+                        continue
                     if '200' in new_m[o]['responses']:
                         if 'items' in new_m[o]['responses']['200']['schema']:
                             props = new_m[o]['responses']['200']['schema']['items']['properties']
@@ -240,7 +245,6 @@ class Plugin():
                             props = new_m[o]['responses']['201']['schema']['items']['properties']
                         else:
                             props = new_m[o]['responses']['201']['schema']['properties']
-                    mthd = new_m[o]['operationId']
                     for p in props:
                         for target in self.halo.settings['mservices'][self.service]['record']['methods'][mthd]['added_fields']:
                             fields = target.split(".")
